# Dash Bio
[![CircleCI](https://circleci.com/gh/plotly/dash-bio/tree/master.svg?style=svg)](https://circleci.com/gh/plotly/dash-bio)

Dash Bio is a suite of bioinformatics components built to work with
[Dash](https://github.com/plotly/dash/).

Announcement: https://medium.com/@plotlygraphs/announcing-dash-bio-ed8835d5da0c

Demo:
[https://dash-bio.plotly.host/Portal/](https://dash-bio.plotly.host/Portal/)

Documentation:
[https://dash.plot.ly/dash-bio](https://dash.plot.ly/dash-bio)

## Components

The Dash Bio components each fall into one of three categories:

- Custom chart types
- Sequence analysis tools
- 3D rendering tools


### Custom chart types

- Dash Circos
- Dash Clustergram
- Dash Needle Plot
- Dash Manhattan Plot
- Dash Volcano Plot

### Sequence analysis tools

- Dash Alignment Viewer
- Dash Sequence Viewer
- Dash Onco Print

### Visualization tools

- Dash MolJS
- Dash Speck

## Dash

Learn more about Dash at
[https://plot.ly/products/dash/](https://plot.ly/products/dash/).

## Consulting and OEM

For inquiries about Dash app development, advanced OEM integration,
and more, please [reach
out](https://plotly.typeform.com/to/mH1Cpb).

## Contributing

If you would like to contribute to this repository, please refer to
the [contributing
guidelines](https://github.com/plotly/dash-bio/blob/master/CONTRIBUTING.md).
